diff --git a/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotReceiveServiceImpl.java b/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotReceiveServiceImpl.java
index 3655ae4e..5a0c561f 100644
--- a/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotReceiveServiceImpl.java
+++ b/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotReceiveServiceImpl.java
@@ -4,12 +4,10 @@ import com.ruoyi.common.core.redis.enums.RedisLockKey;
import com.ruoyi.common.utils.NumberUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.StringUtils;
-import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.iot.constants.ReceiveConstants;
import com.ruoyi.iot.domain.IotDeviceDetail;
import com.ruoyi.iot.domain.ReceiveMsg;
import com.ruoyi.iot.domain.response.CommandResponse;
-import com.ruoyi.iot.enums.ReceiveStatus;
import com.ruoyi.iot.enums.ReceiveType;
import com.ruoyi.iot.service.IotReceiveService;
import com.ruoyi.iot.service.IotService;
@@ -17,10 +15,6 @@ import com.ruoyi.ss.device.domain.Device;
import com.ruoyi.ss.device.domain.enums.DeviceOutageWay;
import com.ruoyi.ss.device.domain.vo.DeviceVO;
import com.ruoyi.ss.device.service.DeviceService;
-import com.ruoyi.ss.suit.domain.enums.SuitFeeType;
-import com.ruoyi.ss.transactionBill.domain.TransactionBillQuery;
-import com.ruoyi.ss.transactionBill.domain.enums.TransactionBillStatus;
-import com.ruoyi.ss.transactionBill.domain.vo.TransactionBillVO;
import com.ruoyi.ss.transactionBill.service.TransactionAssembler;
import com.ruoyi.ss.transactionBill.service.TransactionBillService;
import lombok.extern.slf4j.Slf4j;
@@ -31,7 +25,6 @@ import org.springframework.transaction.support.TransactionTemplate;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.LocalDateTime;
-import java.util.List;
/**
* @author wjh
@@ -66,9 +59,10 @@ public class IotReceiveServiceImpl implements IotReceiveService {
}
// 数据点推送
if (ReceiveType.DATA_POINT.getType().equals(msg.getType())) {
+ log.info("收到推送数据点:{},{},{}", msg.getAt(), msg.getDsId(), msg.getValue());
// 若推送数据点:CSQ,则恢复余额
if (ReceiveConstants.DS_CSQ.equals(msg.getDsId())) {
-// this.recoverBalance(msg);
+ this.recoverBalance(msg);
}
}
// 生命周期
@@ -102,19 +96,18 @@ public class IotReceiveServiceImpl implements IotReceiveService {
// 若有需要恢复余额的设备,则进行操作
if (expireTime != null || ele.compareTo(BigDecimal.ZERO) > 0) {
- BigDecimal finalEle = ele;
transactionTemplate.execute(status -> {
// 记录上次恢复余额的时间
int update = deviceService.updateLastRecoverTime(device.getDeviceId(), msg.getAt());
ServiceUtil.assertion(update != 1, "更新设备信息失败");
- log.info("设备:{} 恢复余额,过期时间:{},剩余电量:{}", device.getMac(), expireTime, finalEle);
+ log.info("设备:{} 恢复余额,过期时间:{},剩余电量:{}", device.getMac(), expireTime, ele);
if (expireTime != null ) {
int setTime = deviceService.setTime(device, expireTime, true, 3);
ServiceUtil.assertion(setTime != 1, "恢复设备时长失败");
}
- if (finalEle.compareTo(BigDecimal.ZERO) > 0) {
- CommandResponse res = iotService.trySetEle(device.getMac(), finalEle, device.getModelProductId(), 3);
+ if (ele.compareTo(BigDecimal.ZERO) > 0) {
+ CommandResponse res = iotService.trySetEle(device, ele, 3);
ServiceUtil.assertion(!res.isSuccess(), "设备电量恢复失败:%s", res.getMsg());
}
@@ -125,55 +118,4 @@ public class IotReceiveServiceImpl implements IotReceiveService {
redisLock.unlock(RedisLockKey.RECOVER_DEVICE_BALANCE, lockKey);
}
}
-
- // 生命周期转设备信息
- private Device parseToDeviceByLife(ReceiveMsg msg) {
- Device device = new Device();
- device.setMac(msg.getDevName());
- device.setOnlineStatus(IotDeviceDetail.Status.toDeviceOnlineStatus(msg.getStatus()).getStatus());
- return device;
- }
-
- // 数据点数据转设备信息
- private Device parseToDevice(ReceiveMsg msg) {
- Device device = new Device();
- device.setMac(msg.getDevName());
-
- if (StringUtils.hasText(msg.getDsId())) {
- String value = msg.getValue().toString();
- switch(msg.getDsId()) {
- case ReceiveConstants.DS_SSID:
- device.setWifi(value);
- break;
- case ReceiveConstants.DS_V:
- device.setVoltage(NumberUtils.nonNullDecimal(value));
- break;
- case ReceiveConstants.DS_P:
- device.setRealTimePower(NumberUtils.nonNullDecimal(value));
- break;
- case ReceiveConstants.DS_A:
- device.setElectricity(NumberUtils.nonNullDecimal(value));
- break;
- case ReceiveConstants.DS_W:
- device.setTotalElectriQuantity(NumberUtils.nonNullDecimal(value).divide(new BigDecimal(1000), 2, RoundingMode.HALF_UP));
- break;
- case ReceiveConstants.DS_S:
- device.setPowerStatus(value);
- break;
- case ReceiveConstants.DS_SET:
- DeviceOutageWay deviceOutageWay = DeviceOutageWay.parse(value);
- device.setOutageWay(deviceOutageWay.getValue());
- break;
- case ReceiveConstants.DS_TIME:
- device.setRemainTime(NumberUtils.nonNullDecimal(value));
- break;
- default:
- break;
- }
- }
-
- return device;
- }
-
-
}
diff --git a/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotServiceImpl.java b/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotServiceImpl.java
index f8807982..204ff10f 100644
--- a/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotServiceImpl.java
+++ b/smart-switch-service/src/main/java/com/ruoyi/iot/service/impl/IotServiceImpl.java
@@ -393,13 +393,13 @@ public class IotServiceImpl implements IotService {
}
@Override
- public CommandResponse trySetTime(String mac, long seconds, String productId, int tryCount) {
- CommandResponse res = this.setTime(mac, seconds, productId);
- if (!res.isSuccess()) {
+ public CommandResponse trySetTime(IotDevice device, long seconds, int tryCount) {
+ CommandResponse res = this.setTime(device, seconds);
+ if (res == null || !res.isSuccess()) {
if (tryCount > 0) {
try {
Thread.sleep(1000);
- return trySetTime(mac, seconds, productId, --tryCount);
+ return trySetTime(device, seconds, --tryCount);
} catch (InterruptedException e) {
throw new RuntimeException(e);
}
@@ -409,13 +409,13 @@ public class IotServiceImpl implements IotService {
}
@Override
- public CommandResponse trySetEle(String mac, BigDecimal ele, String productId, int tryCount) {
- CommandResponse res = this.setEle(mac, ele, productId);
- if (!res.isSuccess()) {
+ public CommandResponse trySetEle(IotDevice device, BigDecimal ele, int tryCount) {
+ CommandResponse res = this.setEle(device, ele);
+ if (res == null || !res.isSuccess()) {
if (tryCount > 0) {
try {
Thread.sleep(1000);
- return trySetEle(mac, ele, productId, --tryCount);
+ return trySetEle(device, ele, --tryCount);
} catch (InterruptedException e) {
throw new RuntimeException(e);
}
diff --git a/smart-switch-service/src/main/java/com/ruoyi/ss/device/mapper/DeviceMapper.xml b/smart-switch-service/src/main/java/com/ruoyi/ss/device/mapper/DeviceMapper.xml
index 09ac49f1..184c1fc5 100644
--- a/smart-switch-service/src/main/java/com/ruoyi/ss/device/mapper/DeviceMapper.xml
+++ b/smart-switch-service/src/main/java/com/ruoyi/ss/device/mapper/DeviceMapper.xml
@@ -147,6 +147,7 @@ PUBLIC "-//mybatis.org//DTD Mapper 3.0//EN"
sd.agent_id,
sd.service_mode,
sd.month_fee,
+ sd.last_recover_time,
sm.model_name as model,
sm.picture as picture,
sm.tags as model_tags,
@@ -171,7 +172,6 @@ PUBLIC "-//mybatis.org//DTD Mapper 3.0//EN"
- order by sd.create_time desc
diff --git a/smart-switch-service/src/main/java/com/ruoyi/iot/service/IotService.java b/smart-switch-service/src/main/java/com/ruoyi/iot/service/IotService.java
index 52d00d75..e466667a 100644
--- a/smart-switch-service/src/main/java/com/ruoyi/iot/service/IotService.java
+++ b/smart-switch-service/src/main/java/com/ruoyi/iot/service/IotService.java
@@ -118,20 +118,21 @@ public interface IotService {
/**
* 尝试设置设备剩余时长
* @param mac MAC
* @param seconds 时长
* @param productId 产品ID
* @param tryCount 尝试次数
*/
- CommandResponse trySetTime(String mac, long seconds, String productId, int tryCount);
+ CommandResponse trySetTime(IotDevice device, long seconds, int tryCount);
+
/**
* 尝试设置设备剩余时长
* @param mac MAC
* @param ele 电量(度)
* @param productId 产品ID
* @param tryCount 尝试次数
*/
- CommandResponse trySetEle(String mac, BigDecimal ele, String productId, int tryCount);
+ CommandResponse trySetEle(IotDevice device, BigDecimal ele, int tryCount);
/**
* 设置设备WIFI
@@ -118,20 +118,21 @@ public interface IotService {
/**
* 尝试设置设备剩余时长
- * @param mac MAC
- * @param seconds 时长
- * @param productId 产品ID
+ *
+ * @param device MAC
+ * @param seconds 时长
* @param tryCount 尝试次数
*/
@@ -118,20 +118,21 @@ public interface IotService {
/**
* 尝试设置设备剩余时长
- * @param mac MAC
- * @param ele 电量(度)
- * @param productId 产品ID
+ *
+ * @param device MAC
+ * @param ele 电量(度)
* @param tryCount 尝试次数
*/